==> option-annotations-2.6.0-sources.jar: io/dekorate/option/config/JvmConfigFluent.java <==
package io.dekorate.option.config;

import java.lang.Integer;
import io.dekorate.project.Project;
import io.dekorate.kubernetes.config.ConfigKey;
import java.lang.Object;
import io.dekorate.kubernetes.config.ConfigurationFluent;
import io.dekorate.option.annotation.SecureRandomSource;
import java.lang.Boolean;
import java.util.Map;
import io.dekorate.option.annotation.GarbageCollector;

 /**
  * Generated
  */
public interface JvmConfigFluent<A extends io.dekorate.option.config.JvmConfigFluent<A>> extends io.dekorate.kubernetes.config.ConfigurationFluent<A>{
  public java.lang.Integer getXms();
  public A withXms(java.lang.Integer xms);
  public java.lang.Boolean hasXms();
  public java.lang.Integer getXmx();
  public A withXmx(java.lang.Integer xmx);
  public java.lang.Boolean hasXmx();
  public java.lang.Boolean getServer();
  public A withServer(java.lang.Boolean server);
  public java.lang.Boolean hasServer();
  public java.lang.Boolean getUseStringDeduplication();
  public A withUseStringDeduplication(java.lang.Boolean useStringDeduplication);
  public java.lang.Boolean hasUseStringDeduplication();
  public java.lang.Boolean getPreferIPv4Stack();
  public A withPreferIPv4Stack(java.lang.Boolean preferIPv4Stack);
  public java.lang.Boolean hasPreferIPv4Stack();
  public java.lang.Boolean getHeapDumpOnOutOfMemoryError();
  public A withHeapDumpOnOutOfMemoryError(java.lang.Boolean heapDumpOnOutOfMemoryError);
  public java.lang.Boolean hasHeapDumpOnOutOfMemoryError();
  public java.lang.Boolean getUseGCOverheadLimit();
  public A withUseGCOverheadLimit(java.lang.Boolean useGCOverheadLimit);
  public java.lang.Boolean hasUseGCOverheadLimit();
  public io.dekorate.option.annotation.GarbageCollector getGc();
  public A withGc(io.dekorate.option.annotation.GarbageCollector gc);
  public java.lang.Boolean hasGc();
  public io.dekorate.option.annotation.SecureRandomSource getSecureRandom();
  public A withSecureRandom(io.dekorate.option.annotation.SecureRandomSource secureRandom);
  public java.lang.Boolean hasSecureRandom();
  
}

==> option-annotations-2.10.0-sources.jar: io/dekorate/option/config/JvmConfigFluent.java <==
package io.dekorate.option.config;

import java.lang.Integer;
import io.dekorate.project.Project;
import io.dekorate.kubernetes.config.ConfigKey;
import java.lang.Object;
import io.dekorate.kubernetes.config.ConfigurationFluent;
import io.dekorate.option.annotation.SecureRandomSource;
import java.lang.Boolean;
import java.util.Map;
import io.dekorate.option.annotation.GarbageCollector;

 /**
  * Generated
  */
public interface JvmConfigFluent<A extends JvmConfigFluent<A>> extends ConfigurationFluent<A>{
  public Integer getXms();
  public A withXms(java.lang.Integer xms);
  public Boolean hasXms();
  public java.lang.Integer getXmx();
  public A withXmx(java.lang.Integer xmx);
  public java.lang.Boolean hasXmx();
  public java.lang.Boolean getServer();
  public A withServer(java.lang.Boolean server);
  public java.lang.Boolean hasServer();
  public java.lang.Boolean getUseStringDeduplication();
  public A withUseStringDeduplication(java.lang.Boolean useStringDeduplication);
  public java.lang.Boolean hasUseStringDeduplication();
  public java.lang.Boolean getPreferIPv4Stack();
  public A withPreferIPv4Stack(java.lang.Boolean preferIPv4Stack);
  public java.lang.Boolean hasPreferIPv4Stack();
  public java.lang.Boolean getHeapDumpOnOutOfMemoryError();
  public A withHeapDumpOnOutOfMemoryError(java.lang.Boolean heapDumpOnOutOfMemoryError);
  public java.lang.Boolean hasHeapDumpOnOutOfMemoryError();
  public java.lang.Boolean getUseGCOverheadLimit();
  public A withUseGCOverheadLimit(java.lang.Boolean useGCOverheadLimit);
  public java.lang.Boolean hasUseGCOverheadLimit();
  public GarbageCollector getGc();
  public A withGc(io.dekorate.option.annotation.GarbageCollector gc);
  public java.lang.Boolean hasGc();
  public SecureRandomSource getSecureRandom();
  public A withSecureRandom(io.dekorate.option.annotation.SecureRandomSource secureRandom);
  public java.lang.Boolean hasSecureRandom();
  public A withServer();
  public A withUseStringDeduplication();
  public A withPreferIPv4Stack();
  public A withHeapDumpOnOutOfMemoryError();
  public A withUseGCOverheadLimit();
  
}
